@@ -188,6 +188,8 @@ class IInclude(ABC):
 
   def update_link(self, text: str) -> str:
     logging.debug("update_link(%s)", text)
+    if "https" in text:
+      return text
     prefix = self.file.include_path.relative_to(self.file.repo.path)
     text = re.sub(r"(\[.*\])\((.*)\)", rf'\1({prefix}/\2)', text.strip())
     return "".join(ch for i, ch in enumerate(text) if i <= 1 or not (text[i - 1] == text[i - 2] == ch == "\n")) + "\n"
